@@ -2,7 +2,7 @@ from dataclasses import dataclass
 from pathlib import Path
 from typing import List
 
-from .ffmpeg import ffmpeg_supports
+from .ffmpeg import MediaType, ffmpeg_supports_types
 from .forward_progress import subprocess_forward_progress
 from .operation import Operation
 
@@ -15,14 +15,13 @@ FFMPEG_TRANSCODE_BASE_ARGS = [
     '-xerror',
     '-v', 'error', 
     '-y',
-    '-i', '-',
-    '-vn']
+    '-i', '-']
 FFMPEG_PRESETS = {
-    'aac-64k': FFMPEGPreset(ext='m4a', args=['-c:a', 'aac', '-b:a', '64k', '-f', 'mp4']),
-    'aac-128k': FFMPEGPreset(ext='m4a', args=['-c:a', 'aac', '-b:a', '128k', '-f', 'mp4']),
-    'mp3-128k': FFMPEGPreset(ext='mp3', args=['-c:a', 'mp3', '-b:a', '128k', '-f', 'mp3']),
-    'mp3-320k': FFMPEGPreset(ext='mp3', args=['-c:a', 'mp3', '-b:a', '320k', '-f', 'mp3']),
-    'flac': FFMPEGPreset(ext='flac', args=['-c:a', 'flac', '-f', 'flac']),
+    'aac-64k': FFMPEGPreset(ext='m4a', args=['-vn', '-c:a', 'aac', '-b:a', '64k', '-f', 'mp4']),
+    'aac-128k': FFMPEGPreset(ext='m4a', args=['-vn', '-c:a', 'aac', '-b:a', '128k', '-f', 'mp4']),
+    'mp3-128k': FFMPEGPreset(ext='mp3', args=['-vn', '-c:a', 'mp3', '-b:a', '128k', '-f', 'mp3']),
+    'mp3-320k': FFMPEGPreset(ext='mp3', args=['-vn', '-c:a', 'mp3', '-b:a', '320k', '-f', 'mp3']),
+    'flac': FFMPEGPreset(ext='flac', args=['-vn', '-c:a', 'flac', '-f', 'flac']),
 }
 
 class FFMPEGTranscoderOperation(Operation):
@@ -42,7 +41,7 @@ class FFMPEGTranscoderOperation(Operation):
         q.wait()
 
     def _job(self, q, file: Path):
-        if ffmpeg_supports(file):
+        if ffmpeg_supports_types([MediaType.Video, MediaType.Audio], file):
             q.info(f"Transcoding...")
             out = self.output_dir / file.with_suffix(self.extension).relative_to(self.root)
             out.parent.mkdir(parents=True, exist_ok=True)
@@ -50,4 +49,7 @@ class FFMPEGTranscoderOperation(Operation):
             errors = subprocess_forward_progress(file, args, "ffmpeg")
             if errors:
                 q.error(errors)
-            q.info(f"Size: {file.stat().st_size // 1024}k -> {out.stat().st_size // 1024}k")
+            if out.exists():
+                q.info(f"Size: {file.stat().st_size // 1024}k -> {out.stat().st_size // 1024}k")
+            else:
+                q.error("Failed to transcode file")
